.. _data:


Data
****

.. currentmodule:: torchkge.data

Knowledge Graph
---------------

.. automodule:: torchkge.data.KnowledgeGraph

.. autoclass:: torchkge.data.KnowledgeGraph.KnowledgeGraph
    :members:
